@@ -53,13 +53,15 @@ class DataServiceApplier:
         glog.info(f"Create DataService: {data_service.id}")
         self.client.create_data_service(data_service.to_proto())
 
-    for i, cred in enumerate(data_service.credentials):
-      data_service.credentials[i] = CredentialApplier(self.client).apply(data_service.id, cred, dry_run)
+    if data_service.credentials is not None:
+      for i, cred in enumerate(data_service.credentials):
+        data_service.credentials[i] = CredentialApplier(self.client).apply(data_service.id, cred, dry_run)
     if after_credentials:
       after_credentials()
 
-    for i, conn in enumerate(data_service.connections):
-      data_service.connections[i] = ConnectionApplier(self.client).apply(data_service.id, conn, dry_run)
+    if data_service.connections is not None:
+      for i, conn in enumerate(data_service.connections):
+        data_service.connections[i] = ConnectionApplier(self.client).apply(data_service.id, conn, dry_run)
     if after_connections:
       after_connections()
 
@@ -86,19 +88,26 @@ class DataServiceApplier:
           self.client.delete_dataflow(data_service.id, df.id)
 
     # TODO - decide on what uniquely defines connections
-    expected = [connection.name for connection in data_service.connections]
-    for connection in self.client.list_connections(data_service.id).data:
-      if connection.name not in expected:
-        glog.info(f"Delete Connection: (ds={data_service.id} id={connection.id.value} {connection.name})")
-        if not dry_run:
-          self.client.delete_connection(data_service.id, connection.id.value)
+    if data_service.connections is not None:
+      expected = [connection.name for connection in data_service.connections]
+      for connection in self.client.list_connections(data_service.id).data:
+        if connection.name not in expected:
+          glog.info(f"Delete Connection: (ds={data_service.id} id={connection.id.value} {connection.name})")
+          if not dry_run:
+            self.client.delete_connection(data_service.id, connection.id.value)
 
-    expected = [credential.name for credential in data_service.credentials]
-    for credential in self.client.list_data_service_credentials(data_service.id).data:
-      if credential.name not in expected:
-        glog.info(f"Delete Credential: (ds={data_service.id} credential_id={credential.credential_id} {credential.name})")
-        if not dry_run:
-          self.client.delete_data_service_credentials(data_service.id, credential.credential_id)
+    if data_service.credentials is not None:
+      expected = [credential.name for credential in data_service.credentials]
+      for credential in self.client.list_data_service_credentials(data_service.id).data:
+        if credential.name not in expected:
+          if len(credential.owner_orgs) != 1:
+            glog.info(
+                f"Skip Delete for Credential shared with multiple data services: (ds={data_service.id} credential_id={credential.credential_id} {credential.name}"
+            )
+            continue
+          glog.info(f"Delete Credential: (ds={data_service.id} credential_id={credential.credential_id} {credential.name})")
+          if not dry_run:
+            self.client.delete_data_service_credentials(data_service.id, credential.credential_id)
 
 
 class CredentialApplier:
@@ -156,7 +165,7 @@ class ConnectionApplier:
         res = self.client.update_connection(data_service_id, connection.id, connection.to_proto())
         # glog.info(res)
         # short term hack as we aren't getting full results from the API on creation (See FP2021-49)
-        existing = self.client.get_connection(data_service_id, res.data.value).data
+        existing = self.client.get_connection(data_service_id, res.data.id.value).data
     else:
       connection.id = ""
       glog.info(f"Create Connection: (ds={data_service_id} id={connection.id} name={connection.name})")
