@@ -3,7 +3,7 @@
 import abc
 import google.protobuf.timestamp_pb2 as timestamp_pb2
 import google.protobuf.wrappers_pb2 as wrappers_pb2
-from typing import List, Dict
+from typing import List, Dict, Optional
 from collections import namedtuple
 
 import ascend.protos.api.api_pb2 as api_pb2
@@ -541,8 +541,8 @@ class DataService(Definition):
                id: str,
                name: str,
                description: str = None,
-               credentials: List[Credential] = [],
-               connections: List[Connection] = [],
+               credentials: Optional[List[Credential]] = None,
+               connections: Optional[List[Connection]] = None,
                dataflows: List[Dataflow] = []):
     """
     Create a DataService definition.
