@@ -47,6 +47,41 @@ class InlineCode:
       return f'''pathlib.Path(os.path.join(os.path.dirname(os.path.realpath(__file__)), {rel_path_components})).read_text(encoding="utf-8")'''
 
 
+def download_component(client: Client, data_service_id: str, dataflow_id: str, component_id: str, resource_base_path: str = "."):
+  """
+  Downloads a Component and writes its definition to a file named `{component_id}.py` under
+  `resource_base_path`. Inline code for PySpark and SQL Transforms are written as separate
+  files in the same folder with the file names derived from the id of the component to
+  which the code belongs. Raises a `ValueError` if `resource_base_path` does not exist.
+
+  Parameters:
+  - client: SDK client
+  - data_service_id: DataService id
+  - dataflow_id: Dataflow id
+  - component_id: Component id
+  - resource_base_path: path to which Component definition will be written
+  are written
+  """
+  if not os.path.isdir(resource_base_path):
+    raise ValueError(f"Specified resource path ({resource_base_path}) must be a directory")
+
+  df_proto = client.get_dataflow(data_service_id=data_service_id, dataflow_id=dataflow_id).data
+  dataflow = dataflow_from_proto(client, data_service_id, df_proto)
+
+  component_path = os.path.join(resource_base_path, f"{component_id}_apply.py")
+  glog.info(f"Writing component definition to ({component_path}) and component resource files to ({resource_base_path})")
+
+  pathlib.Path(resource_base_path).mkdir(parents=True, exist_ok=True)
+
+  rendered_component, inline_code_list = render_component(data_service_id, dataflow, component_id, client.hostname, resource_base_path)
+  for inline_code in inline_code_list:
+    with open(inline_code.resource_path, "w", encoding="utf-8") as f:
+      f.write(inline_code.code)
+
+  with open(component_path, "w", encoding="utf-8") as f:
+    f.write(rendered_component)
+
+
 def download_dataflow(client: Client, data_service_id: str, dataflow_id: str, resource_base_path: str = "."):
   """
   Downloads a Dataflow and writes its definition to a file named `{dataflow_id}.py` under
@@ -140,6 +175,35 @@ class InlineCodeMap:
       return {}
 
 
+def render_component(data_service_id: str, dataflow: Dataflow, component_id: str, hostname: str, base_path: str) -> Tuple[str, List[InlineCode]]:
+  target_component = None
+  inline_code_list: List[InlineCode] = []
+  inline_code_map = InlineCodeMap()
+
+  for component in dataflow.components:
+    if component.id == component_id:
+      target_component = component
+      icl = _inline_code_list_for(component, base_path, base_path)
+      for ic in icl:
+        inline_code_list.append(ic)
+        inline_code_map.add(dataflow.id, component.id, ic)
+  if target_component is None:
+    raise KeyError(f"Component with id of {component_id} not found in dataflow {data_service_id}.{dataflow.id}")
+
+  env = _jinja_env()
+  tmpl = env.get_template("component.jinja")
+  rendered = tmpl.render(data_service_id=data_service_id,
+                         dataflow_id=dataflow.id,
+                         component=target_component,
+                         hostname=hostname,
+                         renderer=_render_definition,
+                         proto_mods=_proto_mods,
+                         gmod_classes=_gmod_classes,
+                         inline_code_map=inline_code_map,
+                         classname_map=_classname_map())
+  return rendered, inline_code_list
+
+
 def render_dataflow(data_service_id: str, dataflow: Dataflow, hostname: str, resource_path: str, base_path: str) -> Tuple[str, List[InlineCode]]:
   inline_code_list: List[InlineCode] = []
   inline_code_map = InlineCodeMap()
@@ -190,7 +254,8 @@ def render_data_service(data_service: DataService, hostname: str, resource_path:
 
 
 _proto_mods = [
-    "ascend", "component", "connection", "content_encoding", "core", "expression", "format", "function", "io", "operator", "pattern", "schema", "text"
+    "ascend", "component", "connection", "content_encoding", "core", "environment", "expression", "format", "function", "io", "operator", "pattern", "schema",
+    "text"
 ]
 
 _gmod_classes = [("google.protobuf.wrappers_pb2", "DoubleValue"), ("google.protobuf.wrappers_pb2", "BoolValue"), ("google.protobuf.wrappers_pb2", "Int64Value"),
